@@ -154,7 +154,7 @@ GObject* tangle_template_create_object_with_id(TangleTemplate* template, const g
 			if (!G_VALUE_HOLDS(&parameter->value, G_TYPE_STRING) || !substitute_parameters(template, &parameter->value)) {
 				g_warning("Invalid signal property '%s' of an object created from the template '%s', skipped.", parameter->name, clutter_get_script_id(G_OBJECT(template)));
 			} else if (template->priv->script) {
-				if (!!tangle_signal_connect_dynamically_from_script(object, parameter->name + 1, g_value_get_string(&parameter->value), template->priv->script)) {
+				if (!tangle_signal_connect_dynamically_from_script(object, parameter->name + 1, g_value_get_string(&parameter->value), template->priv->script)) {
 					g_warning("Failed to connect the signal '%s' of an object created from the template '%s' into function '%s', skipped.", parameter->name + 1, clutter_get_script_id(G_OBJECT(template)), g_value_get_string(&parameter->value));
 				}
 			} else if (!tangle_signal_connect_dynamically(object, parameter->name + 1, g_value_get_string(&parameter->value), NULL)) {
