@@ -453,6 +453,8 @@ void tangle_widget_clamp_child_boundaries(TangleWidget* widget, TangleClamp* cla
 	gfloat original_value;
 	TangleClampDirection direction;
 	GList* child_in_list;
+        ClutterActor* actor;
+        ClutterActorBox actor_box;
 	gfloat child_value;
 	gfloat child_distance;
 	gfloat clamp_distance = G_MAXFLOAT;
@@ -461,14 +463,20 @@ void tangle_widget_clamp_child_boundaries(TangleWidget* widget, TangleClamp* cla
 	
 	original_value = tangle_clamp_get_original_value(clamp);
 	direction = tangle_clamp_get_direction(clamp);
+	g_return_if_fail(direction == TANGLE_CLAMP_HORIZONTAL || direction == TANGLE_CLAMP_VERTICAL);
 	
 	for (child_in_list = TANGLE_WIDGET(widget)->priv->children; child_in_list; child_in_list = child_in_list->next) {
-		if (direction == TANGLE_CLAMP_HORIZONTAL) {
-			child_value = clutter_actor_get_x(CLUTTER_ACTOR(child_in_list->data));
-		} else if (direction == TANGLE_CLAMP_VERTICAL) {
-			child_value = clutter_actor_get_y(CLUTTER_ACTOR(child_in_list->data));
+		actor = CLUTTER_ACTOR(child_in_list->data);
+		if (TANGLE_IS_ACTOR(actor)) {
+			tangle_actor_get_layout_allocation(TANGLE_ACTOR(actor), &actor_box);
 		} else {
-			continue;
+			clutter_actor_get_allocation_box(actor, &actor_box);
+		}
+
+		if (direction == TANGLE_CLAMP_HORIZONTAL) {
+			child_value = actor_box.x1;
+		} else {
+			child_value = actor_box.y1;
 		}
 		if ((child_distance = ABS_F(child_value - original_value)) < clamp_distance) {
 			clamp_distance = child_distance;
